@@ -45,6 +45,9 @@ class JailsReader(ConfigReader):
 		self.__jails = list()
 		self.__force_enable = force_enable
 
+	def getJails(self):
+		return self.__jails
+
 	def read(self):
 		return ConfigReader.read(self, "jail")
 
@@ -60,6 +63,7 @@ class JailsReader(ConfigReader):
 			sections = [ section ]
 
 		# Get the options of all jails.
+		parse_status = True
 		for sec in sections:
 			jail = JailReader(sec, basedir=self.getBaseDir(),
 							  force_enable=self.__force_enable)
@@ -71,8 +75,8 @@ class JailsReader(ConfigReader):
 					self.__jails.append(jail)
 			else:
 				logSys.error("Errors in jail %r. Skipping..." % sec)
-				return False
-		return True
+				parse_status = False
+		return parse_status
 
 	def convert(self, allow_no_files=False):
 		"""Convert read before __opts and jails to the commands stream
