@@ -102,9 +102,11 @@ class Jail:
 		self.__filter = FilterPyinotify(self)
 	
 	def setName(self, name):
+		# 20 based on iptable chain name limit of 30 less len('fail2ban-')
 		if len(name) >= 20:
-			logSys.warning("Jail name %r might be too long and some commands "
-							"might not function correctly. Please shorten"
+			logSys.warning("Jail name %r might be too long and some commands"
+							" (e.g. iptables) might not function correctly."
+							" Please shorten"
 							% name)
 		self.__name = name
 	
