@@ -24,40 +24,23 @@ __author__ = "Cyril Jaquier"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
-import unittest, time
+import time
 import logging, sys
 from server.action import Action
-from StringIO import StringIO
+from utils import LogCaptureTestCase
 
-class ExecuteAction(unittest.TestCase):
+class ExecuteAction(LogCaptureTestCase):
 
 	def setUp(self):
 		"""Call before every test case."""
 		self.__action = Action("Test")
-
-		# For extended testing of what gets output into logging
-		# system, we will redirect it to a string
-		logSys = logging.getLogger("fail2ban")
-
-		# Keep old settings
-		self._old_level = logSys.level
-		self._old_handlers = logSys.handlers
-		# Let's log everything into a string
-		self._log = StringIO()
-		logSys.handlers = [logging.StreamHandler(self._log)]
-		logSys.setLevel(getattr(logging, 'DEBUG'))
+		LogCaptureTestCase.setUp(self)
 
 	def tearDown(self):
 		"""Call after every test case."""
-		# print "O: >>%s<<" % self._log.getvalue()
-		logSys = logging.getLogger("fail2ban")
-		logSys.handlers = self._old_handlers
-		logSys.level = self._old_level
+		LogCaptureTestCase.tearDown(self)
 		self.__action.execActionStop()
 
-	def _is_logged(self, s):
-		return s in self._log.getvalue()
-
 	def testNameChange(self):
 		self.assertEqual(self.__action.getName(), "Test")
 		self.__action.setName("Tricky Test")
@@ -77,6 +60,13 @@ class ExecuteAction(unittest.TestCase):
 		self.assertEqual(Action.substituteRecursiveTags({'A': '<C>'}), {'A': '<C>'})
 		self.assertEqual(Action.substituteRecursiveTags({'A': '<C> <D> <X>','X':'fun'}), {'A': '<C> <D> fun', 'X':'fun'})
 		self.assertEqual(Action.substituteRecursiveTags({'A': '<C> <B>', 'B': 'cool'}), {'A': '<C> cool', 'B': 'cool'})
+		# Multiple stuff on same line is ok
+		self.assertEqual(Action.substituteRecursiveTags({'failregex': 'to=<honeypot> fromip=<IP> evilperson=<honeypot>', 'honeypot': 'pokie', 'ignoreregex': ''}),
+								{ 'failregex': "to=pokie fromip=<IP> evilperson=pokie",
+								  'honeypot': 'pokie',
+								  'ignoreregex': '',
+								})
+
 		# rest is just cool
 		self.assertEqual(Action.substituteRecursiveTags(aInfo),
 								{ 'HOST': "192.0.2.0",
